==> plantuml-libs-6.0.0.tgz: package/distribution/aws-q3-2021/Resource/LoT/AwsIoTReportedState.md <==
# AwsIoTReportedState


```text
aws-q3-2021/Resource/LoT/AwsIoTReportedState
```

```text
include('aws-q3-2021/Resource/LoT/AwsIoTReportedState')
```



| Illustration | AwsIoTReportedState | AwsIoTReportedStateCard | AwsIoTReportedStateGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/LoT/AwsIoTReportedState.png) | ![illustration for AwsIoTReportedState](../../../aws-q3-2021/Resource/LoT/AwsIoTReportedState.Local.png) | ![illustration for AwsIoTReportedStateCard](../../../aws-q3-2021/Resource/LoT/AwsIoTReportedStateCard.Local.png) | ![illustration for AwsIoTReportedStateGroup](../../../aws-q3-2021/Resource/LoT/AwsIoTReportedStateGroup.Local.png) |




## AwsIoTReportedState

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTReportedState
include('aws-q3-2021/Resource/LoT/AwsIoTReportedState')

' renders the element
AwsIoTReportedState('AwsIoTReportedState', 'Aws Io T Reported State', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTReportedState
include('aws-q3-2021/Resource/LoT/AwsIoTReportedState')

' renders the element
AwsIoTReportedState('AwsIoTReportedState', 'Aws Io T Reported State', 'an optional tech label')
@enduml
```

## AwsIoTReportedStateCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTReportedStateCard
include('aws-q3-2021/Resource/LoT/AwsIoTReportedState')

' renders the element
AwsIoTReportedStateCard('AwsIoTReportedStateCard', 'Aws Io T Reported State Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTReportedStateCard
include('aws-q3-2021/Resource/LoT/AwsIoTReportedState')

' renders the element
AwsIoTReportedStateCard('AwsIoTReportedStateCard', 'Aws Io T Reported State Card', 'an optional description')
@enduml
```

## AwsIoTReportedStateGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTReportedStateGroup
include('aws-q3-2021/Resource/LoT/AwsIoTReportedState')

' renders the element
AwsIoTReportedStateGroup('AwsIoTReportedStateGroup', 'Aws Io T Reported State Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTReportedStateGroup
include('aws-q3-2021/Resource/LoT/AwsIoTReportedState')

' renders the element
AwsIoTReportedStateGroup('AwsIoTReportedStateGroup', 'Aws Io T Reported State Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-7.1.0.tgz: package/distribution/aws-q1-2022/Resource/LoT/AwsIoTReportedState.md <==
# AwsIoTReportedState


```text
aws-q1-2022/Resource/LoT/AwsIoTReportedState
```

```text
include('aws-q1-2022/Resource/LoT/AwsIoTReportedState')
```



| Illustration | AwsIoTReportedState | AwsIoTReportedStateCard | AwsIoTReportedStateGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q1-2022/Resource/LoT/AwsIoTReportedState.png) | ![illustration for AwsIoTReportedState](../../../aws-q1-2022/Resource/LoT/AwsIoTReportedState.Local.png) | ![illustration for AwsIoTReportedStateCard](../../../aws-q1-2022/Resource/LoT/AwsIoTReportedStateCard.Local.png) | ![illustration for AwsIoTReportedStateGroup](../../../aws-q1-2022/Resource/LoT/AwsIoTReportedStateGroup.Local.png) |




## AwsIoTReportedState

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsIoTReportedState
include('aws-q1-2022/Resource/LoT/AwsIoTReportedState')

' renders the element
AwsIoTReportedState('AwsIoTReportedState', 'Aws Io T Reported State', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsIoTReportedState
include('aws-q1-2022/Resource/LoT/AwsIoTReportedState')

' renders the element
AwsIoTReportedState('AwsIoTReportedState', 'Aws Io T Reported State', 'an optional tech label')
@enduml
```

## AwsIoTReportedStateCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsIoTReportedStateCard
include('aws-q1-2022/Resource/LoT/AwsIoTReportedState')

' renders the element
AwsIoTReportedStateCard('AwsIoTReportedStateCard', 'Aws Io T Reported State Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsIoTReportedStateCard
include('aws-q1-2022/Resource/LoT/AwsIoTReportedState')

' renders the element
AwsIoTReportedStateCard('AwsIoTReportedStateCard', 'Aws Io T Reported State Card', 'an optional description')
@enduml
```

## AwsIoTReportedStateGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsIoTReportedStateGroup
include('aws-q1-2022/Resource/LoT/AwsIoTReportedState')

' renders the element
AwsIoTReportedStateGroup('AwsIoTReportedStateGroup', 'Aws Io T Reported State Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsIoTReportedStateGroup
include('aws-q1-2022/Resource/LoT/AwsIoTReportedState')

' renders the element
AwsIoTReportedStateGroup('AwsIoTReportedStateGroup', 'Aws Io T Reported State Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
